summaryrefslogtreecommitdiffstats
path: root/libktorrent/torrent/cache.h
diff options
context:
space:
mode:
Diffstat (limited to 'libktorrent/torrent/cache.h')
-rw-r--r--libktorrent/torrent/cache.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/libktorrent/torrent/cache.h b/libktorrent/torrent/cache.h
index 8630bc7..1aff44b 100644
--- a/libktorrent/torrent/cache.h
+++ b/libktorrent/torrent/cache.h
@@ -70,15 +70,15 @@ namespace bt
/**
* Move the data files to a new directory.
* @param ndir The directory
* @return The KIO::Job doing the move
*/
- virtual KIO::Job* moveDataFiles(const TQString & ndir) = 0;
+ virtual TDEIO::Job* moveDataFiles(const TQString & ndir) = 0;
/**
* The move data files job is done.
* @param job The job that did it
*/
- virtual void moveDataFilesCompleted(KIO::Job* job) = 0;
+ virtual void moveDataFilesCompleted(TDEIO::Job* job) = 0;
/**
* Changes output path. All data files should already been moved.
@@ -70,15 +70,15 @@ namespace bt
* Move the data files to a new directory.
* @param ndir The directory
- * @return The KIO::Job doing the move
+ * @return The TDEIO::Job doing the move
*/